// File: /home/sopress/society-v2/wp-content/themes/society/js/_modules.js
var Society = Society || {};
Society.modules= {}
document.addEventListener('DOMContentLoaded', () => {
  for (const module in Society.modules) {
    if ('start' in Society.modules[module]) {
      Society.modules[module].start()
    }
  }
})
window.addEventListener('load', () => {
    for (const module in Society.modules) {
      if ('load' in Society.modules[module]) {
        Society.modules[module].load()
      }
    }
  })
  

// File: /home/sopress/society-v2/wp-content/themes/society/js/includes/api.js

async function api(endpoint, options = {}) {
    options.credentials = 'include';

    const query = options.query || {};

    if (Object.keys(query).length) {
        delete options.query;
        endpoint += '?' + new URLSearchParams(query)
    }

    let root = Society.settings.api;
    if (endpoint.startsWith('/api/')) {
        root = document.location.origin;
    }
    const url = rtrim(root, '/') + '/' + ltrim(endpoint, '/');
    console.log({ url })
    const response = await fetch(url, options);
    if (!response.ok) {
        throw new Error(`HTTP error! Status: ${response.status}`);
    }
    return response.json();
}



// File: /home/sopress/society-v2/wp-content/themes/society/js/includes/string.js
function ltrim(str, chars = "\\s") {
    return str.replace(new RegExp(`^[${chars}]+`), '');
}

function rtrim(str, chars = "\\s") {
    return str.replace(new RegExp(`[${chars}]+$`), '');
}


// File: /home/sopress/society-v2/wp-content/themes/society/js/includes/templates.js
function updateTemplate(templateName, content) {
    const template = document.querySelector(`[data-template="${templateName}"]`);
    if (!template) return;

    template.innerHTML = content;
}



// File: /home/sopress/society-v2/wp-content/themes/society/js/includes/utils.js
function getCanonical() {
    let canonical = document.querySelector('link[rel="canonical"]')?.href;

    if (!canonical) {
        canonical = document.querySelector('meta[property="og:url"]')?.content;
    }

    return canonical || window.location.href.split('#')[0];
}

function getPostId() {
    return Number(document.querySelector('meta[name="post_id"]')?.getAttribute('content')) || false
}

/**
 * Charge dynamiquement un fichier JavaScript externe et exécute une fonction une fois le fichier chargé.
 *
 * @param {string} url - L'URL du fichier JavaScript à charger.
 * @param {function} callback - La fonction à exécuter une fois le fichier chargé.
 */
function loadScript(url, callback) {
    const script = document.createElement('script');
    script.src = url;
    script.async = true;
    script.onload = () => callback();
    script.onerror = () => console.error(`Erreur de chargement du script : ${url}`);
    document.head.appendChild(script);
}
/**
 * Remplace un élément du DOM par un nouveau contenu HTML
 * @param {string|Element} selector Sélecteur CSS ou élément DOM à remplacer
 * @param {string} newHtml Code HTML à insérer à la place
 */
function replaceElementWithHtml(selector, newHtml) {
    const element = typeof selector === 'string' ? document.querySelector(selector) : selector;
    if (!element) return;
  
    const wrapper = document.createElement('div');
    wrapper.innerHTML = newHtml;
  
    // Supprime les <p> vides (sans texte ni enfants)
    wrapper.querySelectorAll('p').forEach(p => {
      if (!p.textContent.trim() && p.children.length === 0) {
        p.remove();
      }
    });
  
    const parent = element.parentNode;
    if (!parent) return;
  
    const fragment = document.createDocumentFragment();
    while (wrapper.firstChild) {
      fragment.appendChild(wrapper.firstChild);
    }
  
    parent.replaceChild(fragment, element);
  }
  


// File: /home/sopress/society-v2/wp-content/themes/society/js/modules/ajax.js
Society.modules.Ajax = (() => {
    let isLoading;
    function loadingEnd() {
        isLoading = false;
        document.querySelectorAll('aria-busy').forEach(element => element.removeAttribute('aria-busy'))
    }
    return {
        grab(url, options = {}) {
            if (isLoading) return Promise.resolve();
            isLoading = true;
            options.loading?.setAttribute('aria-busy', true)

            const selector = options?.selector ?? false;
            return fetch(url)
                .then(response => response.text()).then(html => {
                    if (selector) {
                        let dom = document.implementation.createHTMLDocument().body;
                        dom.innerHTML = html;
                        console.log(selector, html)
                        return dom.querySelector(selector).innerHTML
                    } else {
                        const parser = new DOMParser();
                        const doc = parser.parseFromString(html, 'text/html');
                        return {
                            head: doc.head.innerHTML,
                            body: doc.body.innerHTML,
                        }
                    }
                })
                .catch((error) => {
                    console.error('Erreur:', error);
                })
                .finally(() => {
                    loadingEnd()
                });
        }
    }
})()

Ajax = Society.modules.Ajax;

// File: /home/sopress/society-v2/wp-content/themes/society/js/modules/bookmarks.js
Society.modules.bookmarks = (() => {

    function handleSavePosition() {

        // Sauvegarde de la position lors de l'événement scroll-end
        window.addEventListener('scroll-end', () => {

            if (!document.querySelector('body[data-bookmark]')) return;
            const content = document.querySelector('.content');
            if (!content) return;

            const paragraphs = Array.from(content.querySelectorAll('p'));
            const firstVisibleIndex = paragraphs.findIndex(p => {
                const rect = p.getBoundingClientRect();
                return rect.top >= 0 && rect.top <= window.innerHeight;
            });

            if (firstVisibleIndex !== -1) {

                saveProgress(firstVisibleIndex)
                // localStorage.setItem(location.href + '#scroll-p-index', firstVisibleIndex);
            }

        });
    }

    function getCurrentProgress() {
        return Number(document.body.dataset.progress);
    }
    function handleRestorePosition() {
        if (!document.querySelector('body[data-bookmark]')) return;

        const index = getCurrentProgress();
        if (index > 0) {
            Notifications.generate({
                titre: 'Reprendre votre lecture', texte: 'Voulez-vous reprendre votre lecture là où vous vous étiez arrêté ?', cta: {
                    onclick: () => {
                        const content = document.querySelector('.content');
                        if (!content) return;

                        const paragraphs = content.querySelectorAll('p');
                        const target = paragraphs[parseInt(index, 10)];
                        if (target) {
                            target.scrollIntoView({ behavior: 'smooth', block: 'start' });
                        }
                    }, caption: 'Reprendre'
                }
            })

        }


    }
    function saveProgress(progress) {
        console.log('bookmarsk', { progress, current: getCurrentProgress() });
        if (progress <= getCurrentProgress()) return;

        document.body.dataset.progress = progress
        api('/api/progress/', { query: { pid: getPostId(), progress } }).then(data => {
            console.log(data)
        })
    }
    function set(data) {
        delete document.body.dataset?.bookmark
        delete document.body.dataset?.progress

        if (!data.bookmark) return;
        document.body.dataset.bookmark = true
        document.body.dataset.progress = Number(data?.progress || 0);
    }
    function handleBookmarksButton() {

        document.querySelectorAll('[data-action*="-bookmark"]').forEach(button => button.addEventListener('click', async () => {
            if (button.classList.contains('is-loading')) return;
            if (!Society.modules.Session.isConnected()) {
                return App.modules.modale.open(`
                    <h2>Enregistrez vos articles</h2>
                    <p>Enregistrez <b>les articles qui vous intéressent</b> dans votre compte pour pouvoir <b>les lire plus tard</b>, <b>reprendre là où vous en étiez</b>, ou <b>passer de votre ordinateur à votre téléphone</b>.</p>
                    <p>A l'étape suivante, vous pourrez vous connecter, ou bien créer votre compte si vous n'en avez pas déjà un.</p>
                    `, { cancel: true, cta: { url: '/compte/', caption: 'Continuer' } })
            }
            if (button.dataset.action == 'add-bookmark') {
                const aide_bookmark = await Society.modules.User.get('aide_bookmark');
                if (!aide_bookmark) {
                    return App.modules.modale.open(`
                    <h2>Enregistrez vos articles</h2>
                    <p>Enregistrez <b>les articles qui vous intéressent</b> dans votre compte pour pouvoir <b>les lire plus tard</b>, <b>reprendre là où vous en étiez</b>, ou <b>passer de votre ordinateur à votre téléphone</b>.</p>                    
                    `, {
                        cancel: true,
                        cta: {
                            onclick: async () => {
                                await Society.modules.User.set('aide_bookmark', true);
                                App.modules.modale.close()
                                button.click()
                            }, caption: 'Enregistrer cet article'
                        }
                    })
                }
            }
            button.classList.add('is-loading');
            const action = button.dataset.action.split('-')[0];
            api('/api/bookmark/', { query: { pid: getPostId(), action } }).then(data => {
                set(data)
                if (data.bookmark) {
                    Notifications.generate({ type: 'success', titre: 'Article enregistré', texte: 'Retouvez vos articles enregistrés dans la section "Mon compte".', cta: { url: '/bookmarks', caption: 'Voir mes articles enregistrés' }, temporaire: true })
                }
                button.classList.remove('is-loading');
            })

        }))
    }
    return {
        start() {
            handleBookmarksButton()
            document.addEventListener('session-ready', () => {
                handleSavePosition()
                handleRestorePosition()
            });
        }
        , set
    };
})();


// File: /home/sopress/society-v2/wp-content/themes/society/js/modules/offrir.js
Society.modules.offrir = (() => {
    return {
        start() {
            document.querySelectorAll('[data-action="offrir"]').forEach(item => item.addEventListener('click', async e => {
                if (Society.modules.Session.isAbonne()) {
                    const url = '/offrir?pid=' + getPostId();
                    const aide_gift = await Society.modules.User.get('aide_gift');
                    if (aide_gift) return window.open(url,'_self');
                    return App.modules.modale.open(`
                        <h2>Offrez un morceau de Society!</h2>
                        <p>Vous avez la possibilité d'offrir <b>la lecture intégrale de cet article</b> à une autre personne.</p>
                        <p>Vous devrez saisir l'adresse e-mail de la personne à l'étape suivante.</p>
                        
                        `, { cancel: true, cta: { onclick : async () => {
                            await Society.modules.User.set('aide_gift', true);
                            window.open(url,'_self');
                        }, caption: 'Offrir cet article 🎁' } })
                } else {
                    return App.modules.modale.open(`
                    <h2>Offrez un morceau de Society!</h2>
                    <p>Les abonnés au magazine Society peuvent offrir <b>la lecture intégrale d'un article</b> à une autre personne</p>
                    <p>Seuls les abonnés peuvent offrir la lecture d'un article</p>
                    <p>Si vous avez un compte abonné, vous pourrez vous connecter à l'étape suivante</p>
                    `, { cancel: true, cta: { url: '/compte', caption: 'Se connecter ▶' } })

                }
            }))
        }
    };
})();


// File: /home/sopress/society-v2/wp-content/themes/society/js/modules/pagination.js
Society.modules.Pagination = (() => {
    let Bouton, Site;

    function activerScrollInfini() {
        if (!Bouton) return;
        // Fonction à appeler lors du défilement
        const onScroll = (e) => {
        if (!Bouton) return;

            const windowHeight = window.innerHeight;
            const scroll = window.scrollY;

            const BoutonTop = Bouton.offsetTop;

            const limite = BoutonTop - windowHeight * 2
            if (scroll > limite) {
                Bouton.click();
                window.removeEventListener('scroll', onScroll); // Détacher l'écouteur si le clic ne doit se produire qu'une seule fois
            }
        };

        // Attacher l'écouteur d'événement
        window.addEventListener('scroll', onScroll);
    }
    function activerPaginationHome() {
        if (!Bouton) return;
        Bouton.addEventListener('click', function (e) {
            e.preventDefault();
            let url = Bouton.href;
            Ajax.grab(url, { loading: Bouton, selector: '.main-content' }).then(html => {
                if(!html) return;
                Bouton?.closest('div').remove();
                document.querySelector('.main-content').innerHTML += html;
                document.dispatchEvent(new Event('DOMContentLoaded'));
                start()
            })
        })
    }
    function start() {
        Bouton = document.querySelector('a.auto[href*="/page/"]');
        console.log({ Bouton })
        activerScrollInfini();
        activerPaginationHome();
    }
    return {
        start
    }
})();

// File: /home/sopress/society-v2/wp-content/themes/society/js/modules/pubs.js
Society.modules.Pubs = (() => {
    return {
        load() {

            Sopress.shortcuts.add({
                name: 'Bandeau',
                sequence: ['b'],
                action: () => {
                    App.modules.bandeau.show()
                }
            });

        }
    }
})();

// File: /home/sopress/society-v2/wp-content/themes/society/js/modules/qiota.js
Society.modules.Qiota = (() => {
    const QIOTA_PARTNER_ID = 53;
    // const QIOTA_SCRIPT_SRC = 'https://static.qiota.com/assets/getQiota.js';
    // const QIOTA_TOKEN = '';
    function contentOpened() {
        const urlParams = new URLSearchParams(window.location.search);
        const uid = urlParams.get('uid');
        const hasUid = uid !== null && uid.trim() !== '';
        return hasUid;
    }
    function loadQiota(data) {
        console.log(data.consent ? "Consentement donné, Qiota chargé avec consentement." : "Consentement non donné, Qiota chargé sans consentement.");

        console.log('loadQiota', 'start');
        window.q_token = QIOTA_TOKEN;
        window.q_consent = data.consent || false;
        window.q_logged = false;
        window.q_subscribed = false;

        const qiota = document.createElement('script');
        qiota.src = QIOTA_SCRIPT_SRC + '?consent=' + window.q_consent;
        console.log('qiota.src', qiota.src);
        qiota.id = 'qiota';
        qiota.async = true;
        qiota.onload = () => {
            console.log('loadQiota', 'load');
            console.log('window.q_consent', window.q_consent);

            const pid = getPostId();
            if (pid) {
                window.q_ressource_uri = getCanonical();
                window.q_id_article = pid;
            }
            Society.modules.Session.go();
        };

        (document.head || document.body).appendChild(qiota);
    }


    function checkSirdataConsent(vendorId, callback) {
        __tcfapi('addEventListener', 2, (tcData, success) => {
            if (success && (tcData.eventStatus === 'tcloaded' || tcData.eventStatus === 'useractioncomplete')) {
                const consentOk = tcData.vendor.consents[vendorId] || false;
                callback(consentOk);
            }
        });
    }
    function loadQiotaTest() {
        window.q_type = "keepsession";
        window.q_token = QIOTA_TOKEN;
        window.q_urlcallback = "https://www.societymag.fr/confirmation-achat/";
        window.q_ressource_uri = getCanonical();
        window.q_id_article = getPostId();
        window.q_consent = true;

        const qiota = document.createElement('script');
        qiota.src = QIOTA_SCRIPT_SRC + '?consent=' + window.q_consent;
        qiota.id = 'qiota';
        qiota.async = true;
        qiota.onload = () => {
            console.log('loadQiotaTest', 'load');
            setupQiota(function (response) {
                if (response) {
                    renderQiotaAuth(q_token, q_urlcallback, q_type);
                    return;
                }
            });
        };
        (document.head || document.body).appendChild(qiota);

    }
    function start() {

        // window.addEventListener('scroll', () => {

            if (QIOTA_TEST) {
                return loadQiotaTest()
            }
            const qiotaConsent = sessionStorage.getItem('qiota-consent');
            if (qiotaConsent === null) {
                checkSirdataConsent(QIOTA_PARTNER_ID, consent => {
                    loadQiota({ consent });
                    sessionStorage.setItem('qiota-consent', consent)
                });
            } else {
                loadQiota({ consent: qiotaConsent === 'true' });
            }
        // }, { once: true });
    }

    return { start, loadQiota };
})();


// File: /home/sopress/society-v2/wp-content/themes/society/js/modules/read-status.js
Society.modules.ReadStatus = (() => {
    let swapped = false;

    function getReadIds() {
        return JSON.parse(localStorage.getItem('read_article_ids') || '[]')
    }

    function markAsRead() {
        const postId = typeof getPostId === 'function' ? getPostId() : false
        if (!postId) return

        const read = getReadIds()
        if (!read.includes(postId)) {
            read.push(postId)
            localStorage.setItem('read_article_ids', JSON.stringify(read))
        }
    }

    function swapIfReadOnHome() {
        if (!document.body.classList.contains('home')) return
        if (swapped) return;

        const items = [...document.querySelectorAll('.article-item')]
        if (!items.length) return

        const read = getReadIds()

        const first = items[0]
        const firstId = first.dataset.id
        if (!firstId || !read.includes(parseInt(firstId))) return

        const unreadItem = items.find(item => {
            const id = item.dataset.id
            return id && !read.includes(parseInt(id))
        })

        if (!unreadItem) return

        const parentA = first.parentNode
        const parentB = unreadItem.parentNode

        // Marquer les positions initiales
        const nextA = first.nextSibling
        const nextB = unreadItem.nextSibling

        // Échanger les éléments entre les conteneurs
        parentB.insertBefore(first, nextB)
        parentA.insertBefore(unreadItem, nextA)
        swapped = true;
    }

    function start() {
        return;
        if (document.cookie.includes('user_roles=administrator')) return;
        document.addEventListener('scroll', markAsRead, { once: true })
        swapIfReadOnHome()
    }

    return {
        start
    }

})()


// File: /home/sopress/society-v2/wp-content/themes/society/js/modules/search.js
Society.modules.Search = (() => {

    function start() {
        const searchInput = document.querySelector('form#recherche input[name="s"]');
        let timeout = null;

        if (!searchInput) return;

        searchInput.addEventListener("input", function () {
            clearTimeout(timeout);

            timeout = setTimeout(() => {
                const query = searchInput.value.trim();

                const searchUrl = `./?s=${encodeURIComponent(query)}`;

                fetch(searchUrl)
                    .then(response => response.text())
                    .then(html => {
                        const parser = new DOMParser();
                        const doc = parser.parseFromString(html, "text/html");

                        // Remplace le body de la page avec le nouveau contenu
                        document.querySelector('#taxonomies').innerHTML = doc.querySelector('#taxonomies').innerHTML;
                        document.querySelector('#resultats').innerHTML = doc.querySelector('#resultats').innerHTML;

                        // Met à jour l'URL sans recharger la page
                        window.history.pushState({}, '', searchUrl);

                        // Réattache les événements après mise à jour du DOM
                        document.dispatchEvent(new Event("DOMContentLoaded"));
                    })
                    .catch(error => console.error("Erreur de chargement de la recherche :", error));
            }, 300); // Déclenche après 300ms d'inactivité
        });

        // Gestion de la navigation avec les boutons "Précédent" et "Suivant"
        window.addEventListener("popstate", function () {
            location.reload(); // Recharge la page lorsqu'on navigue dans l'historique
        });
    }

    return {
        start,
    };

})();


// File: /home/sopress/society-v2/wp-content/themes/society/js/modules/session.js
Society.modules.Session = (() => {
    function isConnected() {
        return document.cookie.split('; ').some(cookie =>
            cookie.startsWith("is_connected")
        )
    }

    function deleteIsConnectedCookies() {
        document.cookie.split(';').forEach(cookie => {
            const [rawName] = cookie.split('=');
            const name = rawName.trim();
            if (name.startsWith('is_connected')) {
                document.cookie = `${name}=; expires=Thu, 01 Jan 1970 00:00:00 UTC; path=/`;
            }
        });
    }

    function isAbonne() {
        if (!isConnected()) return false;
        return document.documentElement.dataset.abonne ? true : false
    }
    function loadPostContent(uid = false) {

        if (!uid) return;
        if (window.get_single_content) return;
        window.get_single_content = true;

        if (document.documentElement.dataset.role != 'administrator') {
            fathom.trackEvent('UNLOCK-PAYWL');
            if (document.documentElement.dataset.abonne) {
                fathom.trackEvent('UNLOCK-PAYWL-ABO');
            } else {
                fathom.trackEvent('UNLOCK-PAYWL-OTHERS');
            }
        }

        const qiota = document.querySelector('.article .qiota');
        if (!qiota) return;
        const paywall = document.querySelector('.paywall');
        if (paywall) {
            const paywalled_content = document.querySelector('.paywall')?.innerHTML;
            if (paywalled_content) {
                replaceElementWithHtml(paywall, paywalled_content)
                qiota.remove();
            }
            return;
        }
        const trace = document.querySelector('input[name="trace"]')?.value;
        if (trace) {
            loadScript('https://cdnjs.cloudflare.com/ajax/libs/pako/2.1.0/pako.min.js', function () {
                setContent(decodeAndDecompress(trace));
            })
        } else {
            api('/api/content/', { query: { id: getPostId(), uid } }).then(data => {
                // console.log('get_single_content', data);
                setContent(data.body)
            })
                .catch(error => {
                    console.error('Erreur lors de la requête:', error);
                });
        }
    }

    function decodeAndDecompress(encoded) {
        const compressed = Uint8Array.from(atob(encoded), c => c.charCodeAt(0));
        const decompressed = window.pako.inflate(compressed);
        return new TextDecoder().decode(decompressed);
    }

    function setContent(body) {

        document.querySelector('.article .content>div').innerHTML = body;
        const el = document.querySelector('.article .content>div');
        const rect = el.getBoundingClientRect();

        if (rect.top < 0) {
            el.scrollIntoView({ behavior: 'smooth' });
        }
        document.dispatchEvent(new Event("DOMContentLoaded"));

        // try {
        //     setTimeout(() => {
        //         Neil.loaders()
        //     }, 500);
        // } catch (e) {
        //     console.log(e);
        // }
    }
    function activatePaywall(callback) {
        if (Society?.article?.gratuit) return;

        document.addEventListener('q_newsletter_subscribed', function (e) {
            loadPostContent();
        });

        document.addEventListener('q_qiotaComplete', function (event) {
            if (!event.q_paywallDisplayed) {
                const urlParams = new URLSearchParams(window.location.search);
                const uid = urlParams.get('uid');
                loadPostContent(uid);
            }
        });

        try {
            setupQiota(function (response) {

                setTimeout(() => {
                    document.querySelectorAll('#q_subscribe a').forEach(link => {
                        const url = getCanonical();
                        const href = '/achat.php?page=' + link.href + '&url=' + encodeURI(url);
                        link.href = href;
                    });
                }, 1000)
                console.log('window.q_logged', window.q_logged)
                console.log('window.q_subscribed', window.q_subscribed)
                console.log('window.q_consent', window.q_consent)

                if (window.q_subscribed) {
                    if (window.scrollY) {
                        loadPostContent();
                    } else {
                        window.addEventListener('scroll', loadPostContent, { once: true });
                    }
                }
                if (!response) {
                    console.log('Qiota error :', response);
                    return;
                }
                console.log('Qiota init :', response);
            });
        } catch (e) {
            console.log('Qiota is not ready');
        }
    }
    function go() {
        if (window.sessionready) return activatePaywall();
        window.sessionready = true;

        try {
            Sopress.shortcuts.add({
                name: 'Content',
                sequence: ['c'],
                action: () => {
                    loadPostContent()
                }
            });
        } catch (e) { console.log(e) }

        console.log('session', 'isConnected ?')

        if (!isConnected()) return activatePaywall();
        console.log('session', 'startLoad')
        startLoad('.ctas', 'right');
        api('/api/partial/', { query: { template: 'login-link', pid: getPostId() } })
            .then(data => {
                if (!data || !data.user_id) {
                    // deleteIsConnectedCookies();
                    return;
                }
                Society.modules.bookmarks.set(data);
                updateTemplate('login-link', data.html);
                endLoad('.ctas');

                document.documentElement.dataset.connecte = true;
                document.documentElement.dataset.role = data.role;
                document.documentElement.dataset.abonne = data.is_abonne ? true : false;

                if (data.can_read) {
                    document.body.dataset.lisible = true
                } else {
                    delete document.body.dataset?.lisible

                }

                window.apiNonce = data.nonce;
                window.q_subscribed = (data.is_abonne || data.can_read) ? true : false;
                window.q_logged = true;

                activatePaywall()
                document.dispatchEvent(new CustomEvent("session-ready"));

            }).catch(error => console.error(error)).finally(() => {
                endLoad('.ctas');

            });

    }
    return {
        isAbonne,
        isConnected,
        go,
        activatePaywall
    };
})();

// File: /home/sopress/society-v2/wp-content/themes/society/js/modules/site.js
Society.modules.Site = (() => {

    function preloadPhototext() {
        const link = document.querySelector('link[rel="image_src"][href*="phototext"]')
        if (!link) return;
        const img = document.createElement('img')
        img.src = link.href;
        img.width=1
        img.height=1
        img.addEventListener('load', e => {
            img.remove();
        })
        document.body.append(img);
    }
    function svgSupport() {
        // Check for SVG support and handle the 'no-svg' class
        const supportsSVG = document.createElementNS && document.createElementNS('http://www.w3.org/2000/svg', 'svg').createSVGRect !== undefined;
        if (supportsSVG) {
            const htmlElement = document.documentElement; // Select the <html> element
            htmlElement.classList.remove('no-svg');
            htmlElement.classList.add('svg'); // Optionally add 'svg' class
        }
    }
    function jsSupport() {
        const htmlElement = document.documentElement; // Select the <html> element

        // Remove 'no-js' class (indicating JavaScript is enabled)
        if (htmlElement.classList.contains('no-js')) {
            htmlElement.classList.remove('no-js');
            htmlElement.classList.add('js'); // Optionally add 'js' class
        }
    }
    function start() {
        jsSupport();
        svgSupport();
        document.addEventListener('scroll', preloadPhototext, { once: true })

    }
    return {
        start,
    };
})();

// File: /home/sopress/society-v2/wp-content/themes/society/js/modules/user.js
Society.modules.User = (() => {

    const endpoint = '/wp-json/api/v1/usermeta/';

    /**
     * Écrit une valeur dans les métadonnées utilisateur
     * @param {string} key - Nom de la clé meta
     * @param {any} value - Valeur à stocker
     * @returns {Promise<boolean>} - Succès ou non
     */
    async function set(key, value) {
        const res = await fetch(endpoint + encodeURIComponent(key), {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json',
                'X-WP-Nonce': window.apiNonce
            },
            body: JSON.stringify({ value })
        });
        return res.ok;
    }

    /**
     * Lit une valeur stockée dans les métadonnées utilisateur
     * @param {string} key - Nom de la clé meta
     * @returns {Promise<any>} - Valeur récupérée
     */
    async function get(key) {
        const res = await fetch(endpoint + encodeURIComponent(key), {
            headers: {
                'X-WP-Nonce': window.apiNonce
            }
        });
        if (!res.ok) return null;
        return await res.json();
    }

    return {
        start() {
            document.addEventListener('session-ready', async () => {
                // // Exemple : lecture d'une valeur utilisateur
                // const pref = await get('fav_colour');
                // console.log('User pref loaded:', pref);
            });
        }
        , set
        , get
    };
})();

